/**
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 2010 Bull S.A.S.
 * Contact: jonas-team@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: StopFrameDescriptor.java 20819 2011-02-02 16:00:53Z benoitf $
 * --------------------------------------------------------------------------
 */
package org.ow2.jonas.autostart.stop;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import javax.swing.JOptionPane;

import org.ow2.jonas.autostart.starter.Starter;

/**
 * This class instanciates StopFrame.
 * @author skabore
 */
public class StopFrameDescriptor implements ActionListener {

    /**
     * The starter librairy.
     */
    private Starter starter;

    /**
     * The StopFrame.
     */
    private StopFrame stopFrame;

    /**
     * The constructeur.
     * @param starter the starter librairy
     */
    public StopFrameDescriptor() {
        // this.starter = starter;
        stopFrame = new StopFrame(starter);
        stopFrame.addActionListener(this);
        // stopFrame.addListSelectionListener(this);
    }

    /**
     * The constructeur.
     * @param starter the starter librairy
     */
    public StopFrameDescriptor(final Starter starter) {
        this.starter = starter;
        stopFrame = new StopFrame(starter);
        stopFrame.addActionListener(this);
        // stopFrame.addListSelectionListener(this);
    }

    /**
     * @return starter.
     */
    public final Starter getstarter() {
        return starter;
    }

    /**
     * Set the starter.
     * @param starter the new starter
     */
    public final void setstarter(final Starter starter) {
        this.starter = starter;
    }

    /**
     * @return stopFrame
     */
    public final StopFrame getStopFrame() {
        return stopFrame;
    }

    /**
     * Set the stopFrame.
     * @param stopFrame the stopFrame new value
     */
    public final void setStopFrame(final StopFrame stopFrame) {
        this.stopFrame = stopFrame;
    }

    /**
     * The action performed listener.
     * @param event the event to performed.
     */
    public final void actionPerformed(final ActionEvent event) {
        if (event.getSource() == stopFrame.getJbStop()) {
            stopServer();
        } else if (event.getSource() == stopFrame.getJbStop()) {
            stopFrame.dispose();
        }
    }

    /**
     * Stop the JOnAS server.
     */
    public final void stopServer() {
        new Thread() {
            @Override
            public void run() {
                if (starter.jonasIsRunning()) {
                    starter.getOutput().write("Stopping" + " JOnAS server...");
                    starter.stopJonas();
                } else {
                    showMessage("JOnAS server is not running.");
                }
            }
        }.start();
    }

    /**
     * Show a message dialog.
     * @param message the message to print.
     */
    public final void showMessage(final String message) {
        JOptionPane.showMessageDialog(stopFrame, message, "Informations", JOptionPane.INFORMATION_MESSAGE);
    }

    /**
     * Show a confirm dialog.
     * @return the user response.
     */
    public final int showExitMessage() {
        return JOptionPane.showConfirmDialog(stopFrame, "Are you sure ?", "Confirm dialog", JOptionPane.YES_NO_OPTION);
    }

    public static void main(String[] args) {
        new StopFrameDescriptor();
    }
}
